@@ -20,6 +20,8 @@ from editobj2.editor import *
 from xml.sax.saxutils import escape
 import gobject, gtk
 
+USE_MARKUP_FOR_LABEL = 0
+
 
 class GtkEditorDialog(EditorDialog, gtk.Dialog):
   def __init__(self, gui, direction = "h", on_validate = None, edit_child_in_self = 1, undo_stack = None, on_close = None):
@@ -150,8 +152,6 @@ class GtkAttributePane(AttributePane, gtk.Table):
     self.can_expand = 0
     
   def edit(self, o):
-    #if self.o is o: return
-    
     self.can_expand = 0
     AttributePane.edit(self, o)
     
@@ -247,15 +247,23 @@ class GtkIconPane(IconPane, gtk.HBox):
       self.pack_start(self.image, 0, 1)
       self.image.show_all()
       
-    label   = escape(label)
-    details = escape(details)
-    if details:
-      if self.bold_label: self.label.set_markup("<b>%s</b>\n\n%s\n" % (label, details))
-      else:               self.label.set_markup("%s\n\n%s\n" % (label, details))
-      
+    if USE_MARKUP_FOR_LABEL:
+      if details:
+        self.label.set_markup("%s\n\n%s\n" % (label, details))
+      else:
+        self.label.set_markup(label)
+        
     else:
-      if self.bold_label: self.label.set_markup("<b>%s</b>" % label)
-      else:               self.label.set_markup(label)
+      label   = escape(label)
+      details = escape(details)
+      if details:
+        if self.bold_label: self.label.set_markup("<b>%s</b>\n\n%s\n" % (label, details))
+        else:               self.label.set_markup("%s\n\n%s\n" % (label, details))
+        
+      else:
+        if self.bold_label: self.label.set_markup("<b>%s</b>" % label)
+        else:               self.label.set_markup(label)
+        
     self.show_all()
   
 
@@ -377,7 +385,7 @@ class DynamicNode(object):
       if reorder:
         self.tree.reorder(self.tree.get_iter(self.path()), reorder)
         self.children.sort(lambda a, b: cmp(a.index, b.index))
-      
+        
       i = 0
       iter = self.tree.get_iter(self.path())
       for child in new_children:
@@ -433,7 +441,8 @@ class GtkHierarchyPane(HierarchyPane, gtk.TreeView):
     column.add_attribute(pixbuf_render, "pixbuf", 1)
     text_render = gtk.CellRendererText()
     column.pack_start(text_render)
-    column.add_attribute(text_render, "text", 0)
+    if USE_MARKUP_FOR_LABEL: column.add_attribute(text_render, "markup", 0)
+    else:                    column.add_attribute(text_render, "text"  , 0)
     self.append_column(column)
     
     super(GtkHierarchyPane, self).__init__(gui, master, edit_child, undo_stack)
@@ -501,8 +510,14 @@ class GtkHierarchyPane(HierarchyPane, gtk.TreeView):
       self.last_button      = event.button
       self.last_button_time = event.time
       
-  def _selection_changed(self, *args):
-    tree, rows = self.get_selection().get_selected_rows()
+  def _selection_changed(self, *args): # Require, because some versions of GTK raise the focus_out_event after the selection has changed in the newly-focused widget!
+    import gobject
+    gobject.timeout_add(0, self._selection_changed_delayed)
+    
+  def _selection_changed_delayed(self, *args):
+    selection = self.get_selection()
+    if not selection: return
+    tree, rows = selection.get_selected_rows()
     if len(rows) == 0:
       self.edit_child(None)
       if self.childhood_pane: self.childhood_pane.edit(None, None)
